/* TPUset.c: TPU initialisation program for Kanis VTSplus QSPI functions
 *
 * Copyright (C) 2005  Sieghard Schicktanz <S.Schicktanz@kanis.de>,
 *                                                                      */
/* This program is free software; you can redistribute it and/or        */
/* modify it under the terms of the GNU Library General Public License  */
/* as published by the Free Software Foundation; either version 2       */
/* of the License, or (at your option) any later version.               */
/*                                                                      */
/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU Library General Public License for more details.                 */
 */
/*
   Functions:

   Syntax:
     TPUset [channel]
   where
     channel: TPU channel to read
*/

#include <stdio.h>
#include <ctype.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <asm/tpu_ioctl.h>


#define TPU_CHANNELS	16

static char tpu_dev [] = "/dev/tpu0";


void TPUio (char channel)
{
    unsigned short inp [16];
    unsigned int tpu = 0, i, n;

    if (!strchr ("0123456789abcdef", channel)) {
	printf ("No TPU channel #%c available!\n", channel);
	return;
    }
    tpu_dev [8]= channel;

    if (!(tpu= open (tpu_dev, O_RDONLY))) {
	printf ("Cannot open TPU device %s\n", tpu_dev);
	return;
    }
    printf ("TPU device %s data:\n", tpu_dev);
    for (i= 0; i < (sizeof (inp) >> 1); i++)
	printf (" %4x", i);
    puts ("");

    while ((n= read (tpu, inp, sizeof (inp)))) {
	for (i= 0; i < (n >> 1); i++)
	    printf (" %04x", inp [i]);
	puts ("");
    }
    close (tpu);
}


int usage (void)
{
    puts ("\nSyntax:");
    puts ("\tTPUset [channel]");
    puts ("where");
    puts ("\tchannel: TPU channel to read");
    puts ("");
    return 0;
}


int main (int argc, char *argv[], char *env[])
{
    int uid;

    puts ("Kanis VTSplus TPU read program V.0.0 SchS/Kanis GmbH 032005");

    if (argc <= 1) return usage ();

    if ((uid= getuid ())) {    // are we root already
	printf ("You are not root! UID is %d, trying to set UID 0...", uid);

	if (seteuid (0))      // couldn't become root...
	    puts ("Cannot acquire root privileges!"); return 1;
    }
    TPUio (tolower (*(argv [1])));
    return 0;
}
