/***********************************
 * $Id: m68332_exts.h
 * (C) Copyright 2004, Sieghard Schicktanz (S.Schicktanz@Kanis.de)
 *                                                                      */
/* This program is free software; you can redistribute it and/or        */
/* modify it under the terms of the GNU Library General Public License  */
/* as published by the Free Software Foundation; either version 2       */
/* of the License, or (at your option) any later version.               */
/*                                                                      */
/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU Library General Public License for more details.                 */
/*
 ***************************************
 * Definitions of SIM, QSM and TPU memory structures
 ***************************************
 */

#ifndef __M68332_EXTS_H
#define __M68332_EXTS_H

/*
 * include registers and
 * parameter ram definitions files
 */
// #include <asm/m68332_s.h>
// #include <asm/m68360_pram.h>

/*
 * internal ram
 */
typedef struct sim {
    /* BASE + 0x0000: INTERNAL REGISTERS */
    /* SIM */
    volatile unsigned short     sim_simcr;       /*   +0 module configuration reg */
    volatile unsigned short     sim_simtr;       /*   +2 factory test register    */
    volatile unsigned short     sim_syncr;       /*   +4 PLL control register     */
    volatile unsigned char      RESERVED1;       /*      Reserved area            */
    volatile unsigned char      sim_rsr;         /*   +7 reset status reg         */
    volatile unsigned short     sim_simtre;      /*   +8 module test E register   */
    volatile unsigned char      RESERVED2 [0x7]; /*  +10 Reserved area            */
    /* Parallel I/O */
    volatile unsigned char      pio_porte0;      /*  +17 port E data register (0) */
    volatile unsigned char      RESERVED30;      /*      Reserved area            */
    volatile unsigned char      pio_porte1;      /*  +19 port E data register (1) */
    volatile unsigned char      RESERVED31;      /*      Reserved area            */
    volatile unsigned char      pio_ddre;        /*  +21 port E data direction reg*/
    volatile unsigned char      RESERVED32;      /*      Reserved area            */
    volatile unsigned char      pio_pepar;       /*  +23 port E pin assignment reg*/
    volatile unsigned char      RESERVED33;      /*      Reserved area            */
    volatile unsigned char      pio_portf0;      /*  +25 port F data register (0) */
    volatile unsigned char      RESERVED34;      /*      Reserved area            */
    volatile unsigned char      pio_portf1;      /*  +27 port F data register (1) */
    volatile unsigned char      RESERVED35;      /*      Reserved area            */
    volatile unsigned char      pio_ddrf;        /*  +29 port F data direction reg*/
    volatile unsigned char      RESERVED36;      /*      Reserved area            */
    volatile unsigned char      pio_pfpar;       /*  +31 port F pin assignment reg*/
    /* SIM */
    volatile unsigned char      RESERVED37;      /*      Reserved area            */
    volatile unsigned char      sim_sypcr;       /*  +33 system protection control*/
    volatile unsigned short     sim_picr;        /*  +34 periodic interrupt control reg */
    volatile unsigned short     sim_pitr;        /*  +36 periodic interrupt timing reg */
    volatile unsigned char      RESERVED38;      /*      Reserved area            */
    volatile unsigned char      sim_swsr;        /*  +39 software service         */
    volatile unsigned char      RESERVED4 [0x8]; /*  +40 Reserved area            */
    /* TEST */
    volatile unsigned short     test_tstmsra;    /*  +48 master shift a           */
    volatile unsigned short     test_tstmsrb;    /*  +50 master shift b           */
    volatile unsigned short     test_tstsc;      /*  +52 shift count              */
    volatile unsigned short     test_tstrc;      /*  +54 repetition counter       */
    volatile unsigned short     test_creg;       /*  +56 control                  */
    volatile unsigned short     test_dreg;       /*  +58 distributed register     */
    volatile unsigned char      RESERVED5 [0x5]; /*  +60 Reserved area            */
    volatile unsigned char      pio_portc;       /*  +65 port C data register     */
    volatile unsigned char      RESERVED6 [0x2]; /*  +66 Reserved area            */
    /* MEMC */
    volatile unsigned short     memc_cspar0;     /*  +68 chip select pin assgn (0)*/
    volatile unsigned short     memc_cspar1;     /*  +70 chip select pin assgn (1)*/
    volatile unsigned short     memc_csbarbt;    /*  +72 base register boot       */
    volatile unsigned short     memc_csorbt;     /*  +74 base register boot       */
    volatile unsigned short     memc_csbar0;     /*  +76 base register 0          */
    volatile unsigned short     memc_csor0;      /*  +78 base register 0          */
    volatile unsigned short     memc_csbar1;     /*  +80 base register 1          */
    volatile unsigned short     memc_csor1;      /*  +82 base register 1          */
    volatile unsigned short     memc_csbar2;     /*  +84 base register 2          */
    volatile unsigned short     memc_csor2;      /*  +86 base register 3          */
    volatile unsigned short     memc_csbar3;     /*  +88 base register 3          */
    volatile unsigned short     memc_csor3;      /*  +90 base register 4          */
    volatile unsigned short     memc_csbar4;     /*  +92 base register 4          */
    volatile unsigned short     memc_csor4;      /*  +94 base register 4          */
    volatile unsigned short     memc_csbar5;     /*  +96 base register 5          */
    volatile unsigned short     memc_csor5;      /*  +98 base register 5          */
    volatile unsigned short     memc_csbar6;     /* +100 base register 6          */
    volatile unsigned short     memc_csor6;      /* +102 base register 6          */
    volatile unsigned short     memc_csbar7;     /* +104 base register 7          */
    volatile unsigned short     memc_csor7;      /* +106 base register 7          */
    volatile unsigned short     memc_csbar8;     /* +108 base register 8          */
    volatile unsigned short     memc_csor8;      /* +110 base register 8          */
    volatile unsigned short     memc_csbar9;     /* +112 base register 9          */
    volatile unsigned short     memc_csor9;      /* +114 base register 9          */
    volatile unsigned short     memc_csbar10;    /* +116 base register 10         */
    volatile unsigned short     memc_csor10;     /* +118 base register 10         */
} SIM;

typedef struct qsm {
    /* QSM */
    volatile unsigned short     qsm_qsmcr;       /*   +0 module configuration     */
    volatile unsigned short     qsm_qtest;       /*   +2 module test              */
    volatile unsigned char      qsm_qil [2];     /*   +4 interrupt level & vector */
    volatile unsigned char      RESERVED7 [0x2]; /*   +6 Reserved area            */
    /* SCI */
    volatile unsigned short     sci_sccr0;       /*   +8 sci control (0)          */
    volatile unsigned short     sci_sccr1;       /*  +10 sci control (1)          */
    volatile unsigned short     sci_scsr;        /*  +12 sci status               */
    volatile unsigned short     sci_scdr;        /*  +14 sci data                 */
    volatile unsigned char      RESERVED8 [0x5]; /*  +16 Reserved area            */
    /* PQS */
    volatile unsigned char      pqs_portqs;      /*  +21 pqs data                 */
    volatile unsigned char      pqs_pqspar;      /*  +22 pqs pin assignment       */
    volatile unsigned char      pqs_ddrqs;       /*  +23 pqs data direction       */
    /* SPI */
    volatile unsigned short     spi_spcr0;       /*  +24 spi control (0)          */
    volatile unsigned short     spi_spcr1;       /*  +26 spi control (1)          */
    volatile unsigned short     spi_spcr2;       /*  +28 spi control (2)          */
    volatile unsigned char      spi_spcr3;       /*  +30 spi control (3)          */
    volatile unsigned char      spi_spsr;        /*  +31 spi status               */
    volatile unsigned char      RESERVED9 [224]; /*  +32 Reserved area            */
    /* QUEUE RAM */
    volatile unsigned short     qsm_rr [0x10];   /* +256 receive ram              */
    volatile unsigned short     qsm_tr [0x10];   /* +288 transmit ram             */
    volatile unsigned char      qsm_cr [0x10];   /* +320 command ram              */
} QSM;

typedef struct tpu {
    volatile unsigned short     tpu_tpumcr;      /*  +0 tpu module configuration    */
    volatile unsigned short     tpu_tcr;         /*  +2 test configuration          */
    volatile unsigned short     tpu_dscr;        /*  +4 development support control */
    volatile unsigned short     tpu_dssr;        /*  +6 development support status  */
    volatile unsigned short     tpu_ticr;        /*  +8 tpu interrupt configuration */
    volatile unsigned short     tpu_cier;        /* +10 channel interrupt enable    */
    volatile unsigned short     tpu_cfsr [4];    /* +12 channel function selection  */
    volatile unsigned short     tpu_hsqr [2];    /* +20 host sequence               */
    volatile unsigned short     tpu_hsrr [2];    /* +24 host service request        */
    volatile unsigned short     tpu_cpr  [2];    /* +28 channel priority            */
    volatile unsigned short     tpu_cisr;        /* +32 channel interrupt status    */
    volatile unsigned short     tpu_lr;          /* +34 link register               */
    volatile unsigned short     tpu_sglr;        /* +36 service grant latch         */
    volatile unsigned short     tpu_dcnr;        /* +38 decoded channel number      */
} TPU;

#define sim (*((SIM*) 0xFFFFFA00))
#define qsm (*((QSM*) 0xFFFFFC00))
#define tpu (*((TPU*) 0xFFFFFE00))

#endif

/*
 * Local variables:
 *  c-indent-level: 4
 *  c-basic-offset: 4
 *  tab-width: 4
 * End:
 */
