/* This program is free software; you can redistribute it and/or        */
/* modify it under the terms of the GNU Library General Public License  */
/* as published by the Free Software Foundation; either version 2       */
/* of the License, or (at your option) any later version.               */
/*                                                                      */
/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU Library General Public License for more details.                 */

#ifndef tpu_ioctl_h
#define tpu_ioctl_h

#include <linux/config.h>
#include <asm/ioctl.h>

/* 0x50 is just a magic number to make these relatively unique ('P') */

#define TPUIOCS_SETPAR		0x501	/* set channel function parameters - tpu_default * arg */
#define TPUIOCS_GETPAR		0x502	/* get channel function parameters - tpu_default * arg */
#define TPUIOCS_INIT		0x503	/* initialize channel, set data    - void arg */
#define TPUIOCG_START		0x504	/* start up channel (set priority) - void arg */
#define TPUIOCS_STOP		0x505	/* stop channel (clear priority)   - int arg: 2 */
#define TPUIOCS_SEQUENCE	0x506	/* set host sequence bits          - int arg: 2 */
#define TPUIOCS_SERVICE		0x507	/* set host service bits           - int arg: 2 */
#define TPUIOCS_CLSNOSTOP	0x508	/* set continue operation on close - int arg: 1 */
#define TPUIOCS_OVERWRITE	0x509	/* set overwrite outdated data     - int arg: 1 */
#define TPUIOCS_SETMCR		0x50a	/* set TPU master control register - int arg: 1 */
#define TPUIOCS_GETACT		0x50b	/* get channel active status       - int * arg */
#define TPUIOCS_SETCALL		0x50c	/* set channel callback function   - void (* arg) (int) */


typedef unsigned short PRAM_ch [8];

typedef struct tpu_device
{
	unsigned int channel_func:  4;       /* Channel function code */
	unsigned int host_sequence: 2;       /* Host sequence code */
	unsigned int host_service:  2;       /* Host service code */
	unsigned int priority:      2;       /* Channel priority */
	unsigned int interrupt:     1;       /* Channel interrupt used? */
	unsigned int stop_on_close: 1;       /* Channel stops on close */
	unsigned int overwrite_old: 1;       /* Channel overwrites outdated data */
    	/* the following parameter is NOT modified by TPUIOCS_SETPAR: */
	unsigned int active:        1;       /* Channel is active */
	unsigned char set_mask;              /* Channel data bit mask for parameter RAM setup */
	unsigned char get_mask;              /* Channel data bit mask for reading from parameter RAM */
	unsigned char clr_mask;              /* Channel data bit mask for clearing parameter RAM on IRQ */

	void (* callback) (int);             /* Channel callback function reference */

    	/* the following parameters are NOT modified by ioctl calls: */
	short written;                       /* data buffer write pointer */
	short read;                          /* data buffer read pointer */
    	/* the following parameter is NOT returned by ioctl calls: */
	unsigned short * dbufp;              /* pointer to read data buffer */
} tpu_device;

#endif 
