/*
 * Copyright (C) 2005  S. Schicktanz <S.Schicktanz@Kanis.de>
 *
 * data definitions for TPU parameter RAM access for CPU32 TPU functions
 * used in Kanis GmbH board VTSplus
 *                                                                      */
/* This program is free software; you can redistribute it and/or        */
/* modify it under the terms of the GNU Library General Public License  */
/* as published by the Free Software Foundation; either version 2       */
/* of the License, or (at your option) any later version.               */
/*                                                                      */
/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU Library General Public License for more details.                 */

#ifndef __TPU_PRAM
#define __TPU_PRAM


/*
TPU register assignments:
(Attention: address assignment runs von top to bottom!)

Kanal	CFSR		Host Sequence	Host Service	Priority
 0	0xfffe12:3:0	0xfffe16:1:0	0xfffe1a:1:0	0xfffe1e:1:0
 1	0xfffe12:7:4	0xfffe16:3:2	0xfffe1a:3:2	0xfffe1e:3:2
 2	0xfffe12:11:8	0xfffe16:5:4	0xfffe1a:5:4	0xfffe1e:5:4
 3	0xfffe12:15:12	0xfffe16:7:6	0xfffe1a:7.6	0xfffe1e:7:6
 4	0xfffe10:3:0	0xfffe16:9:8	0xfffe1a:9:8	0xfffe1e:9:8
 5	0xfffe10:7:4	0xfffe16:11:10	0xfffe1a:11:10	0xfffe1e:11:10
 6	0xfffe10:11:8	0xfffe16:13:12	0xfffe1a:13:12	0xfffe1e:13:12
 7	0xfffe10:15:12	0xfffe16:15:14	0xfffe1a:15:14	0xfffe1e:15:14
 8	0xfffe0e:3:0	0xfffe14:1:0	0xfffe18:1:0	0xfffe1c:1:0
 9	0xfffe0e:7:4	0xfffe14:3:2	0xfffe18:3:2	0xfffe1c:3:2
10	0xfffe0e:11:8	0xfffe14:5:4	0xfffe18:5:4	0xfffe1c:5:4
11	0xfffe0e:15:12	0xfffe14:7:6	0xfffe18:7:6	0xfffe1c:7:6
12	0xfffe0c:3:0	0xfffe14:9:8	0xfffe18:9:8	0xfffe1c:9:8
13	0xfffe0c:7:4	0xfffe14:11:10	0xfffe18:11:10	0xfffe1c:11:10
14	0xfffe0c:11:8	0xfffe14:13:12	0xfffe18:13:12	0xfffe1c:13:12
15	0xfffe0c:15:12	0xfffe14:15:14	0xfffe18:15:14	0xfffe1c:15:14
*/

struct TPU_PWM { volatile unsigned char  unused_0;
		 volatile unsigned char  Channel_Control;
		 volatile unsigned short unused_1;
		 volatile unsigned short PWMHI;
		 volatile unsigned short PWMPER;
		 volatile unsigned short unused [4];
	       };

struct TPU_PPWA { volatile unsigned char  Link_Setup;
		  volatile unsigned char  Channel_Control;
		  volatile unsigned char  Max_Count;
		  volatile unsigned char  PERIOD_COUNT;
		  volatile unsigned short ACCUM;
		  volatile unsigned short LAST_ACCUM;
		  volatile unsigned char  ACCUM_RATE;
		  volatile unsigned char  PPWA_UB;
		  volatile unsigned short PPWA_LW;
		  volatile unsigned short unused [2];
	        };

struct TPU_FQM { volatile unsigned short unused [2];
		 volatile unsigned short Channel_Control;
		 volatile unsigned short WINDOW_SIZE;
		 volatile unsigned short PULSE_COUNT;
		 volatile unsigned short IN_WINDOW_ACCUM;
		 volatile unsigned short unused_[2];
	       };

struct TPU_QOM { volatile unsigned char  REF_ADDR;
		 volatile unsigned char  LAST_OFF_ADDR;
		 volatile unsigned char  LOOP_CNT;
		 volatile unsigned char  OFF_PTR;
		 volatile unsigned short OFFSET [6];
	       };

typedef
union TPU_Parameter { struct TPU_PWM  PWM;
		      struct TPU_PPWA PPWA;
		      struct TPU_FQM  FQM;
		      struct TPU_QOM  QOM;
		    } TPU_PRAM;

#define Parameter_RAM ((TPU_PRAM*) 0xFFFFFF00)

#endif
